@@ -114,7 +114,11 @@ class BrightcoveIE(InfoExtractor):
         if it can't be found
         """
         m_brightcove = re.search(
-            r'<object[^>]+?class=([\'"])[^>]*?BrightcoveExperience.*?\1.+?</object>',
+            r'''(?x)<object
+            (?
+                :[^>]+?class=([\'"])[^>]*?BrightcoveExperience.*?\1 |
+                [^>]*?>\s*<param\s+name="movie"\s+value="https?://[^/]*brightcove\.com"
+            ).+?</object>''',
             webpage, re.DOTALL)
         if m_brightcove is not None:
             return cls._build_brighcove_url(m_brightcove.group())
